#! /bin/sh

#cmp_SERVA2SERVB.sh performs MSEED data harmonisation between 2 dataservers.
# input: "config.txt"
# output: "arch_unique.csv", "drop_dupli.csv", "drop_notARCH.csv", "drop_dupli.script", "drop_notARCH.script"
# execution: bash cmp_SERVA2SERVB.sh
# 
#Author: Jiri Kvapil (j.kvapil@ig.cas.cz) - initial version December2017
#Acknowledgments: This work was supported by project COST-action ES1401 "TIDES" / COST CZ LD15029 Ministry of Education, Youth and Sports, Czech Republic
#

# read config file
while read line
do
  col1=`echo $line | awk -F\; '{print $1}'`
  col2=`echo $line | awk -F\; '{print $2}'`
  if [[ $col1 == 'ServerA_path' ]];then
   pathA=$col2
  elif [[ $col1 == 'ServerA_name' ]];then
   servA=$col2
  elif [[ $col1 == 'ServerB_path' ]];then
   pathB=$col2
  elif [[ $col1 == 'ServerB_name' ]];then
   servB=$col2
  elif [[ $col1 == 'Stations' ]];then
   stations=$col2
  elif [[ $col1 == 'Work' ]];then
   work=$col2
  fi
done < config_TEST.csv

if [[ -z $work ]]; then
 work=`pwd`
fi
if [[ -z $servA ]]; then
 servA=SERVA
fi
if [[ -z $servB ]]; then
 servB=SERVB
fi

stamp=`date "+%Y%m%d"`
foldwork="$work"/"$servB"2"$servA"_"$stamp"
if [[ -d $foldwork ]]; then
  rm -rf $foldwork
fi
mkdir $foldwork

echo SERVA: $servA,$pathA
echo SERVB: $servB,$pathB
echo STATIONS: $stations
echo OUT: $foldwork
echo -e "\n"
# end config file

if [[ -d $foldwork ]]; then
  rm -rf $foldwork
fi
mkdir $foldwork

drop1=$foldwork/drop_notARCH.script
drop2=$foldwork/drop_dupli.script

csv0=$foldwork/arch_unique.csv
csv1=$foldwork/drop_notARCH.csv
csv2=$foldwork/drop_dupli.csv

dropfold1=$foldwork/drop_notARCH
dropfold2=$foldwork/drop_dupli

echo "mkdir "$dropfold1 >> $drop1
echo "mkdir "$dropfold2 >> $drop2

echo "ID,FILE,PATH,SIZE" >> $csv0
echo "ID,FILE,PATH,SIZE" >> $csv1
echo "ID,FILE,PATH,SIZE" >> $csv2

id=0
for year in `ls -d ${pathB}/[1-2]??? | awk -F/ '{print $NF}'`
do 
 echo $year
 for jday in `ls -d ${pathB}/${year}/[0-3]?? | awk -F/ '{print $NF}'`
 do
  folder0=$pathB/${year}/$jday
  for pathfile in `ls ${folder0}/* | grep -v '.tgz$'`
  do
   id=$((id+1))
   file=`echo $pathfile | awk -F"/" '{print $NF}'`
   sta=`echo $file | awk -F[.:] '{print $1}'`
   size=`ls -l $pathfile | awk '{print $5}'`
   flagCZ=0
   while read staCZ
   do
    if [[ "$sta" == "$staCZ" ]]; then
     flagCZ=1
    fi
   done < $stations
   if [[ $flagCZ == 0 ]]; then
    echo "mv "$pathfile" "$dropfold1"/"$id"_"$file >> $drop1
    echo $id,$file,$folder0,$size, >> $csv1
   else
    flagUNIQ=1
    for foundref in `find $pathA -type f -name $file | grep $file || echo NOT_FOUND`
    do
     if [[ $foundref != "NOT_FOUND" ]]; then
#      echo $file,FOUND
     # do bytecompare here
     # cmp exit codes 0 for same , 1 for different and 2 for trouble
      if [[ `cmp -s "$pathfile" "$foundref" ; echo $?` == 0 ]]; then
      # echo cmp "$pathfile" "$foundref"
       flagUNIQ=0
      fi
     fi
    done
#    echo $file,$flagUNIQ
    if [[ "$flagUNIQ" == 0 ]]; then
     echo "mv "$pathfile" "$dropfold2"/"$id"_"$file >> $drop2
     echo $id,$file,$folder0,$size, >> $csv2
    elif [[ $flagUNIQ == 1 ]]; then
     echo $id,$file,$folder0,$size, >> $csv0
    fi
   fi
  done
 done
done
